Amari.py
========

.. image:: https://img.shields.io/pypi/v/amari.py.svg
   :target: https://pypi.org/project/amari.py/
   :alt: PyPi Library version
   
.. image:: https://img.shields.io/pypi/pyversions/amari.py.svg
   :target: https://pypi.org/project/amari.py/
   :alt: PyPi library Python versions
   
Amari.py is an async, easy to use API wrapper for the AmariBot.

Installation
------------

Enter any of these commands to install the library:

.. code:: sh

  pip install amari.py

  python -m pip install amari.py

Key features
------------

- Utilizes the whole Amari API
- Asynchronous built
- Anti 429s (rate limiting)

Support
-------

If you have any questions or require support with the API wrapper, visit the `AmariBot Support Server <https://discord.gg/qKkSUSwU2G>`_ and ask in channel it brings you to.

Bugs
----

If you find any bugs with the library, you can report it by creating a bug issue at `Amari.py's Github repo <https://github.com/TheF1ng3r/amari.py>`_.

Docs
----

Visit the `Amari.py docs <https://amaripy.gitbook.io/docs/>`_ for usage of the library.